Sujet virtuel — Documentation audiometry_trainer 0.1.16

# Sujet virtuel

Les réponses du sujet virtuel sont déterminées à partir d’une courbe psychométrique (CP) qui représente la proportion de réponses « Oui » (j’ai entendu un son) en fonction du niveau du stimulus. Une fonction logistique ([KussEtAl2005]; [KingdomAndPrins2016]) est utilisée :

(2)\[\psi(x;\alpha,\beta,\gamma,\lambda) = \gamma + (1-\gamma - \lambda) \left(\frac{1}{1+e^{\beta(\alpha-x)}}\right)\]

où \(\alpha\) est le point médian, \(\beta\) la pente, \(\gamma\) l’asymptote inférieur, et \(\lambda\) l’asymptote supérieur de la CP; \(x\) est le niveau du stimulus auquel la fonction est évaluée.

La figure Courbes psychométriques logistiques montre des exemples de CPs logistiques qui représentent la proportion de réponses « Oui » en fonction du niveau du stimulus. Tous les quatre panneaux affichent la même CP en noise avec une CP de couleur différent qui a A) un point médian différent, B) une pente, et ainsi une largeur, différentes, C) un asymptote inférieur différent, ou D) un asymptote supérieur différent. Les lignes verticales dans A) marquent les points médians des courbes, tandis que dans B) elle masquent la « largeur » de 5% à 95% de réponses « Oui » pour les deux courbes. Les lignes horizontales en pointillé marquent dans tous les panneaux la proportion de réponses correctes au point médian, veillez noter que cela change dans C) et D) en fonction de l’asymptote.

Fig. 3 Courbes psychométriques logistiques

Le point médian est le niveau du stimulus auquel la CP atteigne la moitié de son amplitude, donc pour un sujet virtuel avec \(\gamma = 0\) and \(\lambda=0\), le point médian \(\alpha\) est le niveau du stimulus auquel le sujet donne (sur la longue durée) 50% de réponses « Oui ». La procédure Hughson-Westlake défini le seuil comme le point le plus bas auquel le sujet donne au moins 50% de réponses « Oui » (sur au moins 3 essais). Par conséquent, le seuil (comme défini avec la procédure Hughson-Westlake) se situera généralement à un point égal ou supérieur du point médian \(\alpha\) [MarshallAndJesteadt1986]. C’est tout à fait possible que occasionnellement un seuil soit mesuré à un niveau plus bas que ça car la proportion de réponses « Oui » qu’on retrouve sur un petit nombre d’essais peut être bien différente que la proportion de réponses « Oui » qui sont attendues sur le long terme.

La pente \(\beta\) règle la vitesse à laquelle la CP augmente de sa valeur la plus basse à la plus haute avec l’augmenter du niveau du stimulus. Plutôt de raisonner en termes de pente c’est souvent plus intuitif de raisonner en termes de la « largeur » de la CP ([Alcalá-QuintanaAndGarcía-Pérez2004]; [KussEtAl2005]), qui est corrélée de façon inverse à la pente. `audiometry_trainer` requiert de l’utilisateur la largeur à 90% désirée de la CP pour la génération de fichiers de cas. Par exemple, une largeur de 5 dB indique que la fonction (pour un sujet virtuel avec \(\gamma = 0\) and \(\lambda=0\)) varie d’une probabilité de réponse « Oui » de 5% à 95% avec un changement du niveau du stimulus de 5 dB.

L’asymptote inférieur, \(\gamma\), représente la tendance du sujet à répondre « Oui », même en l’absence de stimulation. Cette tendance n’est pas mesurée de façon formelle dans l’audiométrie clinique [Barr-HamiltonEtAl1969] [MarshallAndJesteadt1986]. Dans une tâche de type Oui/Non avec des essais marqués temporellement, dans lesquels un signal est présenté ou pas, elle serait équivalente au taux de fausses alarmes. Par exemple, un sujet avec un \(\gamma\) de 0.1 répondrait « Oui » dans 1 fois sur 10 dans des essais dans lesquels il n’y avait pas de stimulation. Sous la perspective de la théorie de la détection du signal cette tendance à répondre « Oui » traduit un critère interne qui peut être plus ou moins prudent. Bien que l’estimation de \(\gamma\) nécessite des essais sans signal, ce critère détermine le processus de décision aussi quand un signal est présent, donc la valeur de \(\gamma\) aura une influence sur la CP sous-jacente la procédure d’audiométrie clinique.

L’asymptote supérieur, \(\lambda\), est le taux d’inattention ; il représente la tendance du sujet à rater des réponses à cause de manques d’attention, même pour un stimulus qui est clairement audible.

Lors du masquage clinique avec `audiometry_trainer`, l’effet du bruit est de déplacer le point médian de la CP, si le niveau du bruit qui arrive à la cochlée, en dB de masquage effectif (« effective masking »; EM), dépasse le point médian de la CP. Le déplacement est égal au niveau par lequel le bruit dépasse le point médian. Par exemple, si le niveau du bruit est 5 dB au dessus du point médian non masqué, le point médian masqué sera 5 dB plus haut.

L’efficacité du bruit de masquage varie entre sujets ; pour cette raison une autre variable, `msk_diff`, produit un déplacement ultérieur du point médian de la CP dans la présence de bruit. `msk_diff` est tiré de façon aléatoire d’une distribution Normale avec une moyenne de 0 et une déviation standard de 3 pour chaque combinaison de fréquence/oreille lorsque des fichiers de cas sont générés. Ces valeurs sont basés sur l’observation que les différences dans l’efficacité du bruit de masquage sont de l’ordre d’environ 10 dB (cela est la raison pour laquelle une marge de sécurité de 10 dB est généralement ajoutée pour le calcul du niveau de bruit dans les formules de masquage). Il faut remarquer que `msk_diff` peut être une valeur soit positive, soit négative. Une valeur de `msk_diff` positive signifie que l’effet de masquage est plus grand de l’effet moyen (le point médian de la CP est déplacé vers le haut), tandis qu’une valeur négative de `msk_diff` indique que l’effet de masquage est plus petit de l’effet moyen (le point médian de la CP est déplacé vers le bas).